@@ -2,7 +2,6 @@ from deepmerge import always_merger
 from langdetect import detect, detect_langs
 
 def taxonomy_reference(code, term):
-    print('cenz')
     return dict(
         links=dict(
             self=f'/api/2.0/taxonomies/{code}/{term}'
@@ -92,7 +91,10 @@ def schema_mapping(existing_record, doi):
     if url != None and type(url) is str:
         always_merger.merge(data, {'itemURL': url})
 
-    # itemRelationType
+    # itemResourceType
     always_merger.merge(data, {'itemResourceType': taxonomy_reference('resourceType', 'article')})
 
+    # itemRelationType
+    always_merger.merge(data, {'itemRelationType': taxonomy_reference('itemRelationType', 'isReferencedBy')})
+
     return data
